@@ -78,7 +78,7 @@ get.prob.surface<-function(Twilight.ID, dusk=TRUE, Twilight.time.mat, Twilight.l
  
 		if (Twilight.ID%%10== 1) cat("doing", Twilight.ID, "\n")	
 		
-		Twilight.solar.vector<-solar.FLightR(as.POSIXct(Twilight.time.mat[c(1:24, 26:49), Twilight.ID], tz="gmt", origin="1970-01-01"))
+		Twilight.solar.vector<-solar.FLightR(as.POSIXct(Twilight.time.mat[c(1:24, 26:49), Twilight.ID], tz="GMT", origin="1970-01-01"))
 		Twilight.log.light.vector<-Twilight.log.light.mat[c(1:24, 26:49), Twilight.ID]
 		Twilight.time.vector=Twilight.time.mat[c(1:24, 26:49), Twilight.ID]
 		
@@ -217,7 +217,7 @@ get.current.slope.prob <-function (x, calibration = NULL, Twilight.solar.vector
         stop("either time_correction or Twilight.solar.vector should be provided to get.current.slope.prob!")
 		
 	if (is.null(Twilight.solar.vector))  {
-	Twilight.solar.vector<-solar.FLightR(as.POSIXct(Twilight.time.vector, tz="gmt", origin="1970-01-01"))
+	Twilight.solar.vector<-solar.FLightR(as.POSIXct(Twilight.time.vector, tz="GMT", origin="1970-01-01"))
 	}    
 	Probability = 0
     Data <- check.boundaries(x, Twilight.solar.vector = Twilight.solar.vector, 
@@ -268,7 +268,7 @@ get.current.slope.prob <-function (x, calibration = NULL, Twilight.solar.vector
 check.boundaries<-function(x, Twilight.solar.vector=NULL,  Twilight.log.light.vector, plot=FALSE, verbose=FALSE,  log.light.borders=log(c(2,64)), log.irrad.borders=c(-15, 50), dusk=TRUE, impute.on.boundaries=FALSE, Twilight.time.vector=NULL) {
 # this function...
 	if (is.null(Twilight.solar.vector))  {
-	Twilight.solar.vector<-solar.FLightR(as.POSIXct(Twilight.time.vector, tz="gmt", origin="1970-01-01"))
+	Twilight.solar.vector<-solar.FLightR(as.POSIXct(Twilight.time.vector, tz="GMT", origin="1970-01-01"))
 	}
 	Elevs<-elevation.FLightR(x[[1]], x[[2]], Twilight.solar.vector)
 	LogIrrad<-log(get.Irradiance(Elevs*pi/180)+1e-20)
@@ -473,22 +473,24 @@ check.boundaries<-function(x, Twilight.solar.vector=NULL,  Twilight.log.light.ve
 	if (verbose) print(Res)
 	# and now we want to return 
 	if (plot) {
+        oldpar <- graphics::par(no.readonly = TRUE)    
+        on.exit(graphics::par(oldpar))   
 		Coef<-try(stats::coef(stats::lm(Res[,1]~Res[,2])))
 		if (class(Coef)!='try-error') {
-		    graphics::plot(LogLight~LogIrrad, main=paste(twilight=as.POSIXct(Twilight.time.vector[24], tz="gmt", origin="1970-01-01"), ifelse(dusk, "dusk", "dawn"), "intercept", Coef[1], "slope", Coef[2]), xlim=c(log.irrad.borders[1]-3, log.irrad.borders[2]+3), ylim=c(log.light.borders[1]-1, log.light.borders[2]+1))
+		    graphics::plot(LogLight~LogIrrad, main=paste(twilight=as.POSIXct(Twilight.time.vector[24], tz="GMT", origin="1970-01-01"), ifelse(dusk, "dusk", "dawn"), "intercept", Coef[1], "slope", Coef[2]), xlim=c(log.irrad.borders[1]-3, log.irrad.borders[2]+3), ylim=c(log.light.borders[1]-1, log.light.borders[2]+1))
 		    print(Coef)
 		} else {
-		   graphics::plot(LogLight~LogIrrad, main=paste(twilight=as.POSIXct(Twilight.time.vector[24], tz= "gmt", origin="1970-01-01"), ifelse(dusk, "dusk", "dawn"), "intercept NA slope NA"), xlim=c(log.irrad.borders[1]-3, log.irrad.borders[2]+3))
+		   graphics::plot(LogLight~LogIrrad, main=paste(twilight=as.POSIXct(Twilight.time.vector[24], tz= "GMT", origin="1970-01-01"), ifelse(dusk, "dusk", "dawn"), "intercept NA slope NA"), xlim=c(log.irrad.borders[1]-3, log.irrad.borders[2]+3))
 		}
 		   graphics::points(Res[,1]~Res[,2], col="red", lwd=2, pch="+")
 		   graphics::par(ask = TRUE)
 	    if (class(Coef)!='try-error') {
-		   graphics::plot(LogLight~LogIrrad, main=paste(twilight=as.POSIXct(Twilight.time.vector[24], tz="gmt", origin="1970-01-01"), ifelse(dusk, "dusk", "dawn"), "intercept", Coef[1], "slope", Coef[2]), xlim=c(log.irrad.borders[1]-3, log.irrad.borders[2]+3), ylim=c(log.light.borders[1]-1, log.light.borders[2]+1))
+		   graphics::plot(LogLight~LogIrrad, main=paste(twilight=as.POSIXct(Twilight.time.vector[24], tz="GMT", origin="1970-01-01"), ifelse(dusk, "dusk", "dawn"), "intercept", Coef[1], "slope", Coef[2]), xlim=c(log.irrad.borders[1]-3, log.irrad.borders[2]+3), ylim=c(log.light.borders[1]-1, log.light.borders[2]+1))
 		} else {
-		   graphics::plot(LogLight~LogIrrad, main=paste(twilight=as.POSIXct(Twilight.time.vector[24], tz= "gmt", origin="1970-01-01"), ifelse(dusk, "dusk", "dawn"), "intercept NA slope NA"), xlim=c(log.irrad.borders[1]-3, log.irrad.borders[2]+3))
+		   graphics::plot(LogLight~LogIrrad, main=paste(twilight=as.POSIXct(Twilight.time.vector[24], tz= "GMT", origin="1970-01-01"), ifelse(dusk, "dusk", "dawn"), "intercept NA slope NA"), xlim=c(log.irrad.borders[1]-3, log.irrad.borders[2]+3))
 		}
 		graphics::par(ask=FALSE)
-		if (Coef[1]<(-6)) warning("check twilight at around ", as.POSIXct(Twilight.time.vector[24], tz="gmt", origin="1970-01-01"), " it had strange shading\n")
+		if (Coef[1]<(-6)) warning("check twilight at around ", as.POSIXct(Twilight.time.vector[24], tz="GMT", origin="1970-01-01"), " it had strange shading\n")
 
 	}
 	return(Res)
