@@ -1,10 +1,11 @@
 
 test_that('plot_lon_lat_works',  {
+   #skip_on_os('solaris')
    File<-system.file("extdata", "Godwit_TAGS_format.csv", package = "FLightR")
-   Proc.data<-get.tags.data(File, end.date=as.POSIXct('2013-07-02', tz='GMT'))
+   Proc.data<-get.tags.data(File, end.date=as.POSIXct('2013-10-02', tz='GMT'))
    Calibration.periods<-data.frame(
         calibration.start=NA,
-        calibration.stop=as.POSIXct("2013-08-20"),
+        calibration.stop=as.POSIXct("2013-08-20", tz='GMT'),
 		lon=5.43, lat=52.93) 
    Calibration<-make.calibration(Proc.data, Calibration.periods, likelihood.correction=FALSE)
    Grid<-make.grid(left=0, bottom=50, right=10, top=56,
@@ -20,10 +21,10 @@ test_that('plot_lon_lat_works',  {
 
 test_that('map_flightr_ggmap_works',  {
    File<-system.file("extdata", "Godwit_TAGS_format.csv", package = "FLightR")
-   Proc.data<-get.tags.data(File, end.date=as.POSIXct('2013-07-02', tz='GMT'))
+   Proc.data<-get.tags.data(File, end.date=as.POSIXct('2013-10-02', tz='GMT'))
    Calibration.periods<-data.frame(
         calibration.start=NA,
-        calibration.stop=as.POSIXct("2013-08-20"),
+        calibration.stop=as.POSIXct("2013-08-20", tz='GMT'),
         lon=5.43, lat=52.93) 
    Calibration<-make.calibration(Proc.data, Calibration.periods, likelihood.correction=FALSE)
    Grid<-make.grid(left=0, bottom=50, right=10, top=56,
@@ -35,16 +36,16 @@ test_that('map_flightr_ggmap_works',  {
    if (utils::packageVersion('ggmap')[1]>=2.7) {
    if (ggmap::has_google_key()) {
          # not too clever but it looks like that other ways of graphics test are not stable..
-         p<-map.FLightR.ggmap(Result, seasonal.donut.location=NULL,return.ggobj=TRUE, zoom=5, save=FALSE)    
+         p<-map.FLightR.ggmap(Result, seasonal.donut.location=NULL,return.ggobj=TRUE, zoom=5, save=FALSE, plot.cloud=FALSE)    
          expect_equal(length(p), 9)
    } else {
       expect_error({
-         p<-map.FLightR.ggmap(Result, seasonal.donut.location=NULL,return.ggobj=TRUE, zoom=5, save=FALSE)    
+         p<-map.FLightR.ggmap(Result, seasonal.donut.location=NULL,return.ggobj=TRUE, zoom=5, save=FALSE, plot.cloud=FALSE)    
       })
       }
       } else {
       expect_error({
-         p<-map.FLightR.ggmap(Result, seasonal.donut.location=NULL,return.ggobj=TRUE, zoom=5, save=FALSE)    
+         p<-map.FLightR.ggmap(Result, seasonal.donut.location=NULL,return.ggobj=TRUE, zoom=5, save=FALSE, plot.cloud=FALSE)    
       })
    } 
    }
@@ -53,10 +54,10 @@ test_that('map_flightr_ggmap_works',  {
 
  test_that('plot_util_distr_works',  {
    File<-system.file("extdata", "Godwit_TAGS_format.csv", package = "FLightR")
-   Proc.data<-get.tags.data(File, end.date=as.POSIXct('2013-07-02', tz='GMT'))
+   Proc.data<-get.tags.data(File, end.date=as.POSIXct('2013-10-02', tz='GMT'))
    Calibration.periods<-data.frame(
         calibration.start=NA,
-        calibration.stop=as.POSIXct("2013-08-20"),
+        calibration.stop=as.POSIXct("2013-08-20", tz='GMT'),
 		lon=5.43, lat=52.93) 
    Calibration<-make.calibration(Proc.data, Calibration.periods, likelihood.correction=FALSE)
    Grid<-make.grid(left=0, bottom=50, right=10, top=56,
@@ -68,7 +69,7 @@ test_that('map_flightr_ggmap_works',  {
    if (utils::packageVersion('ggmap')[1]>=2.7) {
    if (ggmap::has_google_key()) {
    # not too clever but it looks like that other ways of graphics test are not stable..
-   expect_output(plot_util_distr(Result, zoom=5, save=FALSE))
+   expect_type(plot_util_distr(Result, zoom=5, save=FALSE), 'list')
    } else {
       expect_error(plot_util_distr(Result, zoom=5, save=FALSE))
    }
@@ -86,7 +87,7 @@ test_that('map_flightr_ggmap_works',  {
     Proc.data<-get.tags.data(File, end.date=as.POSIXct('2013-07-02', tz='GMT'))
     Calibration.periods<-data.frame(
          calibration.start=NA,
-         calibration.stop=as.POSIXct("2013-08-20"),
+         calibration.stop=as.POSIXct("2013-08-20", tz='GMT'),
 		 lon=5.43, lat=52.93) 
     Calibration<-make.calibration(Proc.data, Calibration.periods, likelihood.correction=FALSE)
     Grid<-make.grid(left=0, bottom=50, right=10, top=56,
